%define	major		1
%define	libname		%mklibname sndfile %{major}
%define develname	%mklibname sndfile -d

%define build_octave 0

%define bootstrap 0
%{?_without_bootstrap: %global bootstrap 0}
%{?_with_bootstrap: %global bootstrap 1}

Summary:	A library to handle various audio file formats
Name:		libsndfile
Version:	1.2.0
%define subrel 2
Release:	%mkrel 3
License:	LGPLv2+
Group:		System/Libraries
URL:		https://libsndfile.github.io/libsndfile/
Source0:	https://github.com/libsndfile/libsndfile/archive/%{version}/%{name}-%{version}.tar.gz
#
# Security Patches
# P100 -> ...
#
Patch101:		libsndfile-psf_strlcpy_crlf-fix-CVE-2015-8075.patch
# not yet upstreamed, CVE-2018-19758, bsc#1117954
Patch102:		libsndfile-wav-loop-count-fix.patch
# CVE: CVE-2022-33065
Patch103:		libsndfile-CVE-2022-33065.patch
#from upstream, for <= 1.2.2, rhbz#2322326
Patch104:		libsndfile-1.2.2-cve-2024-50612.patch
BuildRequires:	cmake
BuildRequires:	ninja
BuildRequires:	lame-devel
BuildRequires:	pkgconfig(libmpg123)
BuildRequires:	pkgconfig(ogg)
BuildRequires:	pkgconfig(opus)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	pkgconfig(flac)
BuildRequires:	pkgconfig(alsa)
BuildRequires:	pkgconfig(sndio)
BuildRequires:	pkgconfig(speex)
%if !%{bootstrap}
%ifarch %{ix86} x86_64
BuildRequires:	nasm
%endif
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(samplerate)
%endif
BuildRequires:	pkgconfig(python3)

%description
libsndfile is a C library for reading and writing sound files such as
AIFF, AU and WAV files through one standard interface. It can currently
read/write 8, 16, 24 and 32-bit PCM files as well as 32-bit floating
point WAV files and a number of compressed formats.

%package -n	%{libname}
Summary:	Shared library of sndfile
Group:		System/Libraries

%description -n	%{libname}
libsndfile is a C library for reading and writing sound files such as
AIFF, AU and WAV files through one standard interface. It can currently
read/write 8, 16, 24 and 32-bit PCM files as well as 32-bit floating
point WAV files and a number of compressed formats.

This package contains the shared library to run applications based on
libsndfile.

%package -n	%{develname}
Summary:	Libraries, includes, etc to develop libsndfile applications
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	libflac-devel
Provides:	sndfile-devel = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Libraries, include files, etc you can use to develop libsndfile applications.

%package	progs
Summary:	Example progs based on libsndfile
Group:		Sound/Utilities

%description	progs
This contains sndfile-info for printing information about a sound
file and sndfile-play for playing a sound file.


%if %{build_octave}
%package	octave
Summary:	Octave modules based on libsndfile
Group:		Sound
BuildRequires:	pkgconfig(octave)

%description	octave
This contains octave modules based on libsndfile for reading, writing and
playing audio files.
%endif

%prep
%autosetup -p1

%build
%cmake -GNinja \
  -DENABLE_CPACK=OFF \
  -DBUILD_TESTING=OFF \
  -DENABLE_EXPERIMENTAL=ON \
  -DBUILD_EXAMPLES=OFF \
  -DCMAKE_INSTALL_DOCDIR=%{_defaultdocdir}/libsndfile
%cmake_build

%install
%cmake_install

rm -rf %{buildroot}%{_datadir}/doc/libsndfile

%files -n %{libname}
%doc AUTHORS CHANGELOG.md README.md
%license COPYING
%{_libdir}/libsndfile.so.%{major}{,.*}

%files -n %{develname}
%doc CHANGELOG.md
%license COPYING
%{_libdir}/libsndfile.so
%{_includedir}/sndfile.h
%{_includedir}/sndfile.hh
%{_libdir}/pkgconfig/sndfile.pc
%{_libdir}/cmake/SndFile/

%files progs
%doc CHANGELOG.md
%license COPYING
%{_bindir}/sndfile-*
%{_mandir}/man1/*

%if %{build_octave}
%files octave
%{_datadir}/octave/
%{_libdir}/octave/*/site/oct/*/*.oct
%endif


%changelog
* Sun Nov 24 2024 daviddavid <daviddavid> 1.2.0-3.2.mga9
+ Revision: 2118818
- add fedora patch to fix CVE-2024-50612 (mga#33789)
- backport upstream patch to fix CVE-2022-33065 (mga#32480)
+ wally <wally>
- build using cmake + ninja
- drop multiarch support

* Sat Jan 14 2023 wally <wally> 1.2.0-2.mga9
+ Revision: 1932919
- fix libdir in pkgconf .pc file
- enable non-bootstrap build

* Mon Jan 09 2023 daviddavid <daviddavid> 1.2.0-1.mga9
+ Revision: 1931901
- new version: 1.2.0
- switch to cmake build system
- enable MPEG/MP3 support
- remove merged upstream patches

* Sun Nov 20 2022 wally <wally> 1.0.31-6.mga9
+ Revision: 1909270
- rebuild for flac 1.4.2

* Sat Mar 26 2022 umeabot <umeabot> 1.0.31-5.mga9
+ Revision: 1828068
- Mageia 9 Mass Rebuild

* Mon Dec 06 2021 neoclust <neoclust> 1.0.31-4.mga9
+ Revision: 1761004
- Add P104: Fix improper buffer reusing (#732) (mga#29735)

* Sat Jul 31 2021 neoclust <neoclust> 1.0.31-3.mga9
+ Revision: 1738324
- Add P103: Fixes CVE-2021-3246 (mga#29298)
+ daviddavid <daviddavid>
- update Url

* Thu Mar 25 2021 daviddavid <daviddavid> 1.0.31-2.mga9
+ Revision: 1709784
- add BR opus to enable external FLAC/Ogg/Vorbis/Opus support (mga#28639)

* Wed Mar 03 2021 luigiwalser <luigiwalser> 1.0.31-1.mga9
+ Revision: 1696736
- 1.0.31

* Thu Nov 19 2020 luigiwalser <luigiwalser> 1.0.30-1.mga8
+ Revision: 1647385
- 1.0.30
- remove upstreamed patches

* Mon Jun 22 2020 joequant <joequant> 1.0.28-12.mga8
+ Revision: 1598428
- rebuild

* Wed Apr 29 2020 daviddavid <daviddavid> 1.0.28-11.mga8
+ Revision: 1573133
- add a single upstream patch that fixes CVE-2018-1966[12] and CVE-2017-1745[67] (mga#26562)

* Sun Feb 16 2020 umeabot <umeabot> 1.0.28-10.mga8
+ Revision: 1536686
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 22 2019 mrambo3501 <mrambo3501> 1.0.28-9.mga8
+ Revision: 1455160
- add debian patch which fixes CVE-2019-3832 (mga#25275)

* Sat May 04 2019 daviddavid <daviddavid> 1.0.28-8.mga7
+ Revision: 1396329
- add opensuse patch to fix CVE-2018-19758 (mga#24752)
- disable and drop static libraries

* Sun Sep 23 2018 umeabot <umeabot> 1.0.28-7.mga7
+ Revision: 1299157
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 mrambo3501 <mrambo3501> 1.0.28-6.mga7
+ Revision: 1250104
- add suse patches which fix CVE-2017-1745[6-7] and CVE-2018-13139 (mga#23382)

* Fri May 04 2018 luigiwalser <luigiwalser> 1.0.28-5.mga7
+ Revision: 1226073
- add patches from opensuse and upstream to fix CVE-2017-1424[56] and CVE-2017-14634

* Fri Sep 08 2017 mrambo3501 <mrambo3501> 1.0.28-4.mga7
+ Revision: 1151987
- Added upsteam patch which fixes CVE-2017-12562 mga#21618

* Sat Jun 24 2017 luigiwalser <luigiwalser> 1.0.28-3.mga6
+ Revision: 1108340
- add patch from fedora to fix CVE-2017-6892

* Mon Jun 05 2017 luigiwalser <luigiwalser> 1.0.28-2.mga6
+ Revision: 1106802
- add patches from opensuse to fix CVE-2017-836[1235]

* Tue May 16 2017 luigiwalser <luigiwalser> 1.0.28-1.mga6
+ Revision: 1102225
- 1.0.28

* Wed Aug 10 2016 luigiwalser <luigiwalser> 1.0.27-1.mga6
+ Revision: 1045288
- 1.0.27

* Sun Jan 03 2016 luigiwalser <luigiwalser> 1.0.26-1.mga6
+ Revision: 918821
- 1.0.26
- remove patches 0, 2, 3, and 4 (fixed upstream)

* Tue Nov 17 2015 luigiwalser <luigiwalser> 1.0.25-10.mga6
+ Revision: 903903
- add patches from opensuse to fix CVE-2015-7805 and CVE-2015-8075

* Thu Dec 25 2014 luigiwalser <luigiwalser> 1.0.25-9.mga5
+ Revision: 805967
- rediff upstream patch to fix buffer overreads

* Wed Dec 24 2014 luigiwalser <luigiwalser> 1.0.25-8.mga5
+ Revision: 805445
- add upstream patch to fix potential divide-by-zero

* Wed Oct 15 2014 umeabot <umeabot> 1.0.25-7.mga5
+ Revision: 748210
- Second Mageia 5 Mass Rebuild

* Thu Sep 18 2014 pterjan <pterjan> 1.0.25-6.mga5
+ Revision: 694914
- Rebuild to fix dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.0.25-5.mga5
+ Revision: 681789
- Mageia 5 Mass Rebuild

* Sun Jul 06 2014 wally <wally> 1.0.25-4.mga5
+ Revision: 647092
- add patch to fix linking

* Fri Oct 18 2013 umeabot <umeabot> 1.0.25-3.mga4
+ Revision: 507338
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 1.0.25-2.mga3
+ Revision: 358180
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 30 2012 ovitters <ovitters> 1.0.25-1.mga3
+ Revision: 323454
- clean spec
- fix rpm group

* Mon Jul 18 2011 fwang <fwang> 1.0.25-1.mga2
+ Revision: 125599
- new version 1.0.25

* Mon Jul 04 2011 ahmad <ahmad> 1.0.24-1.mga2
+ Revision: 117985
- Update to 1.0.24
- Add .tar.gz.asc Source

* Sun Mar 27 2011 colin <colin> 1.0.23-2.mga1
+ Revision: 78002
- Rebuild against new flac to get rid of 64 bit libdir path error
+ dmorgan <dmorgan>
- Remove mdv macros
  Bootstrap libsndfile
- imported package libsndfile


* Sun Oct 10 2010 Götz Waschk <waschk@mandriva.org> 1.0.23-1mdv2011.0
+ Revision: 584532
- update to new version 1.0.23

* Mon Oct 04 2010 Oden Eriksson <oeriksson@mandriva.com> 1.0.22-1mdv2011.0
+ Revision: 582847
- 1.0.22

* Wed Dec 16 2009 Götz Waschk <waschk@mandriva.org> 1.0.21-2mdv2010.1
+ Revision: 479219
- rebuild, the src.rpm was lost
- new version
- fix source URL

* Wed Dec 02 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.20-6mdv2010.1
+ Revision: 472550
- Rebuild

* Wed Dec 02 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1.0.20-5mdv2010.1
+ Revision: 472549
- Rebuild

* Sun Nov 08 2009 Götz Waschk <waschk@mandriva.org> 1.0.20-4mdv2010.1
+ Revision: 463218
- make devel packages parallely installable (bug #55361)

* Sun Sep 27 2009 Olivier Blin <oblin@mandriva.com> 1.0.20-3mdv2010.0
+ Revision: 449995
- keep nasm for x86_64 too

* Sun Sep 27 2009 Olivier Blin <oblin@mandriva.com> 1.0.20-2mdv2010.0
+ Revision: 449909
- add bootstrap flag for jack (from Arnaud Patard)
- use nasm on x86 only (from Arnaud Patard)

* Thu May 14 2009 Frederik Himpe <fhimpe@mandriva.org> 1.0.20-1mdv2010.0
+ Revision: 375705
- Update to new version 1.0.20

* Tue Mar 03 2009 Götz Waschk <waschk@mandriva.org> 1.0.19-1mdv2009.1
+ Revision: 347863
- update to new version 1.0.19

* Sat Feb 07 2009 Funda Wang <fwang@mandriva.org> 1.0.18-3mdv2009.1
+ Revision: 338398
- 1.0.18 final

* Tue Jan 13 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.18-2.pre25.1mdv2009.1
+ Revision: 328819
- update to new prerelease 25
- drop patch 0

* Mon Dec 08 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.18-2.pre24h.1mdv2009.1
+ Revision: 311954
- add missing buildrequires on libvorbis-devel, libsamplerate-devel and celt-devel
- update to new prerelease 24h

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 1.0.18-2.pre22.1mdv2009.0
+ Revision: 264893
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Tue May 27 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.18-1.pre22.1mdv2009.0
+ Revision: 211739
- update to new prerelease 1.0.18.pre22
- add missing buildrequires on nasm, libalsa-devel, libjack-devel and autogen
- Patch0: fix compilation with gcc-4.3
- do not package INSTALL file

* Thu Feb 21 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.18-1.pre20.1mdv2008.1
+ Revision: 173754
- new prerelease
- new license policy

* Fri Jan 11 2008 Thierry Vignaud <tv@mandriva.org> 1.0.18-1.pre19.1mdv2008.1
+ Revision: 148600
- rebuild
- kill re-definition of %%buildroot on Pixel's request
- do not package big ChangeLog

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Fri Dec 07 2007 Götz Waschk <waschk@mandriva.org> 1.0.18-0.pre19.1mdv2008.1
+ Revision: 116243
- new version

* Mon Oct 22 2007 Götz Waschk <waschk@mandriva.org> 1.0.18-0.pre18.1mdv2008.1
+ Revision: 101137
- new version

* Wed Oct 10 2007 Götz Waschk <waschk@mandriva.org> 1.0.18-0.pre17.1mdv2008.1
+ Revision: 96686
- new prerelease
- drop the patch
- add support for octave, but disable it by default

* Mon Oct 01 2007 Götz Waschk <waschk@mandriva.org> 1.0.18-0.pre11.7mdv2008.0
+ Revision: 94331
- fix oden's fix
- security update (bug #34388, CVE-2007-4974)

  + Oden Eriksson <oeriksson@mandriva.com>
    - fix CVE-2007-4974

* Wed Jun 27 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.18-0.pre11.6mdv2008.0
+ Revision: 44810
- add more provides

* Sun Jun 24 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.18-0.pre11.5mdv2008.0
+ Revision: 43667
- adjust obsoletes

* Sat Jun 23 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.18-0.pre11.4mdv2008.0
+ Revision: 43482
- new devel library policy

* Thu Jun 14 2007 Helio Chissini de Castro <helio@mandriva.com> 1.0.18-0.pre11.3mdv2008.0
+ Revision: 39359
- Add flac requires. If you intend to compile with flac resources, prefer external library instead of internal one, conflicting with libflac-devel on includes install

* Thu Jun 14 2007 Götz Waschk <waschk@mandriva.org> 1.0.18-0.pre11.2mdv2008.0
+ Revision: 39316
- remove conflicting flac headers

* Wed Jun 13 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.18-0.pre11.1mdv2008.0
+ Revision: 38952
- prerelease 11
- fix file list
- spec file clean

* Tue May 01 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1.0.18-0.pre8.1mdv2008.0
+ Revision: 20133
- update to the 1.0.18pre8 version
- drop P0
- drop auto* aclocal actions


* Mon Dec 11 2006 Götz Waschk <waschk@mandriva.org> 1.0.17-5mdv2007.0
+ Revision: 94980
- fix buildrequires
- fix buildrequires
- fix buildrequires
- Import libsndfile

* Mon Dec 11 2006 Götz Waschk <waschk@mandriva.org> 1.0.17-3mdv2007.1
- patch for new libflac

* Mon Sep 04 2006 Emmanuel Andry <eandry@mandriva.org> 1.0.17-2mdv2007.0
- add provides for static package

* Fri Sep 01 2006 Götz Waschk <waschk@mandriva.org> 1.0.17-1mdv2007.0
- update file list
- New release 1.0.17

* Mon May 01 2006 Götz Waschk <waschk@mandriva.org> 1.0.16-1mdk
- New release 1.0.16

* Fri Mar 17 2006 Götz Waschk <waschk@mandriva.org> 1.0.15-1mdk
- New release 1.0.15

* Tue Feb 21 2006 Götz Waschk <waschk@mandriva.org> 1.0.14-1mdk
- New release 1.0.14

* Mon Jan 23 2006 Götz Waschk <waschk@mandriva.org> 1.0.13-1mdk
- New release 1.0.13
- use mkrel

* Wed Oct 05 2005 Götz Waschk <waschk@mandriva.org> 1.0.12-1mdk
- fix buildrequires
- New release 1.0.12

* Mon Nov 15 2004 Goetz Waschk <waschk@linux-mandrake.com> 1.0.11-1mdk
- New release 1.0.11

* Thu Jun 17 2004 Götz Waschk <waschk@linux-mandrake.com> 1.0.10-1mdk
- fix url
- reenable libtoolize
- New release 1.0.10

* Fri Apr 02 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.0.9-1mdk
- 1.0.9
- fix libtoolize

